<?php

/*-----------------------------------------------------------------------------------*/
/* Enqueu scripts */
/*-----------------------------------------------------------------------------------*/   

if (!function_exists('messaggero_enqueue_scripts')) {

	function messaggero_enqueue_scripts() {

		wp_deregister_style('avventura-lite-style');
		wp_deregister_style('avventura-lite-' . esc_attr(get_theme_mod('avventura_lite_skin', 'orange')));

		wp_enqueue_style( 'avventura-lite-parent-style' , get_template_directory_uri() . '/style.css' ); 

		wp_enqueue_style(
			'messaggero-' . esc_attr(get_theme_mod('avventura_lite_skin', 'orange')),
			get_stylesheet_directory_uri() . '/assets/skins/' . esc_attr(get_theme_mod('avventura_lite_skin', 'orange')) . '.css',
			array( 'messaggero-style' ),
			'1.0.0'
		); 

		wp_enqueue_style('messaggero-style' , get_stylesheet_directory_uri() . '/style.css'); 

		$googleFontsArgs = array(
			'family' =>	str_replace('|', '%7C','Merriweather:300,300i,400,400i,700,700i,900,900i'),
			'subset' =>	'latin,latin-ext'
		);
		
		wp_deregister_style('google-fonts');
		wp_enqueue_style('google-fonts', add_query_arg ( $googleFontsArgs, "https://fonts.googleapis.com/css" ), array(), '1.0.0' );

		wp_enqueue_style(
			'owl.carousel',
			get_stylesheet_directory_uri() . '/assets/css/owl.carousel.css', 
			array(), '2.3.4'
		);

		wp_enqueue_style(
			'owl.theme.default',
			get_stylesheet_directory_uri() . '/assets/css/owl.theme.default.css', 
			array(), '2.3.4'
		);

		wp_enqueue_style(
			'messaggero-owl-theme',
			get_stylesheet_directory_uri() . '/assets/css/messaggero.owl.theme.css', 
			array(), '1.0.0'
		);

		wp_enqueue_script(
			'owl.carousel',
			get_stylesheet_directory_uri() . '/assets/js/owl.carousel.js',
			array('jquery'),
			'2.3.4', 
			TRUE
		);

		wp_enqueue_script(
			'messaggero-script',
			get_stylesheet_directory_uri() . '/assets/js/script.js',
			array('jquery'),
			'1.0.0', 
			TRUE
		);

	}
	
	add_action( 'wp_enqueue_scripts', 'messaggero_enqueue_scripts', 999);

}

/*-----------------------------------------------------------------------------------*/
/* Replace hooks */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('messaggero_replace_hooks')) {

	function messaggero_replace_hooks() {
		
		remove_action('avventura_lite_slick_slider', 'avventura_lite_slick_slider_function');
		remove_action('avventura_lite_top_sidebar', 'avventura_lite_top_sidebar_function');
		remove_action('avventura_lite_thumbnail', 'avventura_lite_thumbnail_function');
		remove_action('post_class', 'avventura_lite_post_class');
		remove_action( 'avventura_lite_before_content', 'avventura_lite_before_content_function' );
		remove_action( 'avventura_lite_default_format', 'avventura_lite_default_format_function' );
		remove_action( 'avventura_lite_image_format', 'avventura_lite_image_format_function' );
		
		remove_action( 'avventura_lite_link_format', 'avventura_lite_link_format_function' );
		remove_action( 'avventura_lite_quote_format', 'avventura_lite_quote_format_function' );
		
		remove_action( 'avventura_lite_page_format', 'avventura_lite_page_format_function' );
		remove_filter('the_content_more_link', 'avventura_lite_hide_excerpt_more');
		remove_filter('excerpt_more', 'avventura_lite_hide_excerpt_more');
		remove_filter('get_the_excerpt', 'avventura_lite_customize_excerpt_more' );

	}
	
	add_action('init','messaggero_replace_hooks');

}

/*-----------------------------------------------------------------------------------*/
/* Exclude sticky posts on home */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('messaggero_is_featured_posts_on_archive')) {

	function messaggero_is_featured_posts_on_archive() {
		
		if (
			is_author() ||
			is_category() ||
			is_tag() ||
			is_tax('post_format')
		) :
		
			return true;
			
		else :

			return false;

		endif;

	}

}

/*-----------------------------------------------------------------------------------*/
/* GET POSTS ON SLIDESHOW */
/*-----------------------------------------------------------------------------------*/

if (!function_exists('messaggero_get_posts_on_slideshow')) {

	function messaggero_get_posts_on_slideshow() {

		return intval(avventura_lite_setting('messaggero_featured_posts_items', 3)) * 4;

	}

}

/*-----------------------------------------------------------------------------------*/
/* Exclude featured posts on homepage */
/*-----------------------------------------------------------------------------------*/   

if (!function_exists('messaggero_exclude_featured_posts_on_home')) {

	function messaggero_exclude_featured_posts_on_home(&$query) {
		
		if ( 
			(
				$query->is_home() && 
				$query->is_main_query() &&
				strstr(avventura_lite_setting('messaggero_post_slideshow_layout','layout-1'), 'layout' ) == true
			) ||
			( 
				$query->is_archive() &&
				$query->is_main_query() &&
				messaggero_is_featured_posts_on_archive() == true &&
				strstr(avventura_lite_setting('messaggero_post_slideshow_layout','layout-1'), 'layout' ) == true
			)			
		){ 
	
			$offset = messaggero_get_posts_on_slideshow();
			
			$ppp = get_option('posts_per_page');
		
			if ( $query->is_paged ) {
				
				$page_offset = $offset + ( ($query->query_vars['paged']-1) * $ppp );
				$query->set('offset', $page_offset );
		
			}
			else {
				$query->set('offset',$offset);
			}
	
		}
	
	}

	add_action('pre_get_posts', 'messaggero_exclude_featured_posts_on_home', 1 );

}

/*-----------------------------------------------------------------------------------*/
/* Adjust offset pagination */
/*-----------------------------------------------------------------------------------*/   

if (!function_exists('messaggero_adjust_offset_pagination')) {

	function messaggero_adjust_offset_pagination($found_posts, $query) {
	
		$offset = messaggero_get_posts_on_slideshow();
	
		if ( 
			(
				$query->is_home() && 
				$query->is_main_query() &&
				strstr(avventura_lite_setting('messaggero_post_slideshow_layout','layout-1'), 'layout' ) == true
			) ||
			( 
				$query->is_archive() &&
				$query->is_main_query() &&
				messaggero_is_featured_posts_on_archive() == true &&
				strstr(avventura_lite_setting('messaggero_post_slideshow_layout','layout-1'), 'layout' ) == true
			)			
		){ 
			return $found_posts - $offset;
		}
		
		return $found_posts;
	
	}

	add_filter('found_posts', 'messaggero_adjust_offset_pagination', 1, 2 );

}

/*-----------------------------------------------------------------------------------*/
/* Get categories */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('messaggero_get_categories')) {

	function messaggero_get_categories() {

		$args = array(
			'taxonomy' => 'category',
			'hide_empty' => true,
		);

		$return['none'] = esc_attr__( 'None','messaggero');

		foreach ( get_terms($args) as $cat) {
			$return[$cat->term_id] = $cat->name;
		}
		
		return $return;

	}

}

/*-----------------------------------------------------------------------------------*/
/* Customize register */
/*-----------------------------------------------------------------------------------*/   

if (!function_exists('messaggero_customize_register')) {

	function messaggero_customize_register( $wp_customize ) {

		$wp_customize->remove_control( 'avventura_lite_header_layout');
		$wp_customize->remove_section( 'slideshow_section');
		$wp_customize->remove_control( 'avventura_lite_home');
		$wp_customize->remove_control( 'avventura_lite_category_layout');
		$wp_customize->remove_control( 'avventura_lite_search_layout');
		$wp_customize->remove_control( 'avventura_lite_view_readmore');
		$wp_customize->remove_section( 'layouts_section');

		$wp_customize->remove_control('header_text');
   
		$wp_customize->add_setting( 'messaggero_hide_site_title', array(
			'default' => false,
			'sanitize_callback' => 'messaggero_checkbox_sanize',
			'transport'  => 'refresh'
		));
		
		$wp_customize->add_control( 'messaggero_hide_site_title', array(
			'label' => esc_html__( 'Hide Site Title','messaggero'),
			'section' => 'title_tagline',
			'type' => 'checkbox',
		));
	   
		$wp_customize->add_setting( 'messaggero_hide_tagline', array(
			'default' => true,
			'sanitize_callback' => 'messaggero_checkbox_sanize',
			'transport'  => 'refresh'
		));
		
		$wp_customize->add_control( 'messaggero_hide_tagline', array(
			'label' => esc_html__( 'Hide Tagline','messaggero'),
			'section' => 'title_tagline',
			'type' => 'checkbox',
		));

		$wp_customize->add_section('messaggero_post_slideshow_section', array(
			'title' => esc_html__( 'Messaggero Post Slideshow', 'messaggero' ),
			'description' => esc_html__( 'Messaggero Post Slideshow', 'messaggero' ),
			'priority' => 12,

		));

		$wp_customize->add_setting( 'messaggero_post_slideshow_layout', array(
			'default' => 'layout-1',
			'sanitize_callback' => 'messaggero_select_sanitize',
		));

		$wp_customize->add_control( 'messaggero_post_slideshow_layout' , array(
			'priority' => 9,
			'type' => 'select',
			'section' => 'messaggero_post_slideshow_section',
			'label' => esc_html__('Grid layout','messaggero'),
			'description' => esc_html__('Please select one of available layouts for the desktop devices.','messaggero'),
			'choices'  => array (
			   'disable' => esc_html__( 'Disable','messaggero'),
			   'layout-1' => esc_html__( 'Layout 1','messaggero'),
			   'layout-2' => esc_html__( 'Layout 2','messaggero'),
			   'layout-3' => esc_html__( 'Layout 3','messaggero'),
			   'layout-4' => esc_html__( 'Layout 4','messaggero'),
			),
		));
		
		$wp_customize->add_setting( 'messaggero_featured_posts_items', array(
			'default' => '3',
			'sanitize_callback' => 'messaggero_select_sanitize',
		));

		$wp_customize->add_control( 'messaggero_featured_posts_items' , array(
			'priority' => 9,
			'type' => 'select',
			'section' => 'messaggero_post_slideshow_section',
			'label' => esc_html__('Slideshow items','messaggero'),
			'description' => esc_html__('Please note that, since it is a post grid, each slide contains 4 articles.','messaggero'),
			'choices'  => array (
			   '1' => esc_html__( '1 slide with 4 posts','messaggero'),
			   '2' => esc_html__( '2 slide with 8 posts','messaggero'),
			   '3' => esc_html__( '3 slide with 12 posts','messaggero'),
			   '4' => esc_html__( '4 slide with 16 posts','messaggero'),
			   '5' => esc_html__( '5 slide with 20 posts','messaggero'),
			),
		));
		
		$wp_customize->add_setting( 'messaggero_slideshow_dots', array(
			'default' => true,
			'sanitize_callback' => 'messaggero_checkbox_sanize',
			'transport'  => 'refresh'
		));
		
		$wp_customize->add_control( 'messaggero_slideshow_dots', array(
			'label' => esc_html__( 'Show Dots','messaggero'),
			'section' => 'messaggero_post_slideshow_section',
			'type' => 'checkbox',
		));
		
		$wp_customize->add_panel( 'messaggero_postblock_panel', array(
			'title' => esc_html__( 'Messaggero Post Blocks', 'messaggero' ),
			'description' => esc_html__( 'Messaggero Post Block', 'messaggero' ),
			'priority' => 13,
		));
		
		$wp_customize->add_section('messaggero_postblock_1', array(
			'title' => esc_html__( 'Messaggero postBlock 1', 'messaggero' ),
			'panel' => 'messaggero_postblock_panel',
		));
	
		$wp_customize->add_setting( 'messaggero_postblock_1_category', array(
			'default' => 'none',
			'sanitize_callback' => 'messaggero_select_sanitize',

		));

		$wp_customize->add_control( 'messaggero_postblock_1_category' , array(
			'type' => 'select',
			'section' => 'messaggero_postblock_1',
			'label' => esc_html__('Category','messaggero'),
			'description' => esc_html__('Please select the category of this postblock.','messaggero'),
			'choices'  => messaggero_get_categories(),
		));
		
		$wp_customize->add_setting( 'messaggero_postblock_1_layout', array(
			'default' => 'module-1',
			'sanitize_callback' => 'messaggero_select_sanitize',

		));

		$wp_customize->add_control( 'messaggero_postblock_1_layout' , array(
			'type' => 'select',
			'section' => 'messaggero_postblock_1',
			'label' => esc_html__('Layout','messaggero'),
			'description' => esc_html__('Please select the layout of this postblock.','messaggero'),
			'choices'  => array (
			   'disable' => esc_html__( 'Disable','messaggero'),
			   'module-1' => esc_html__( 'Module 1','messaggero'),
			   'module-2' => esc_html__( 'Module 2','messaggero'),
			   'module-3' => esc_html__( 'Module 3','messaggero'),
			   'module-4' => esc_html__( 'Module 4','messaggero'),
			),
		));

		$wp_customize->add_setting( 'messaggero_postblock_1_style', array(
			'default' => 'dark',
			'sanitize_callback' => 'messaggero_select_sanitize',

		));

		$wp_customize->add_control( 'messaggero_postblock_1_style' , array(
			'type' => 'select',
			'section' => 'messaggero_postblock_1',
			'label' => esc_html__('Style','messaggero'),
			'description' => esc_html__('Please select the style of this postblock.','messaggero'),
			'choices'  => array (
			   'light' => esc_html__( 'Light','messaggero'),
			   'dark' => esc_html__( 'Dark','messaggero'),
			),
		));

		$wp_customize->add_section('messaggero_postblock_2', array(
			'title' => esc_html__( 'Messaggero postBlock 2', 'messaggero' ),
			'panel' => 'messaggero_postblock_panel',
		));
	
		$wp_customize->add_setting( 'messaggero_postblock_2_category', array(
			'default' => 'none',
			'sanitize_callback' => 'messaggero_select_sanitize',

		));

		$wp_customize->add_control( 'messaggero_postblock_2_category' , array(
			'type' => 'select',
			'section' => 'messaggero_postblock_2',
			'label' => esc_html__('Category','messaggero'),
			'description' => esc_html__('Please select the category of this postblock.','messaggero'),
			'choices'  => messaggero_get_categories(),
		));
		
		$wp_customize->add_setting( 'messaggero_postblock_2_layout', array(
			'default' => 'disable',
			'sanitize_callback' => 'messaggero_select_sanitize',

		));

		$wp_customize->add_control( 'messaggero_postblock_2_layout' , array(
			'type' => 'select',
			'section' => 'messaggero_postblock_2',
			'label' => esc_html__('Layout','messaggero'),
			'description' => esc_html__('Please select the layout of this postblock.','messaggero'),
			'choices'  => array (
			   'disable' => esc_html__( 'Disable','messaggero'),
			   'module-1' => esc_html__( 'Module 1','messaggero'),
			   'module-2' => esc_html__( 'Module 2','messaggero'),
			   'module-3' => esc_html__( 'Module 3','messaggero'),
			   'module-4' => esc_html__( 'Module 4','messaggero'),
			),
		));

		$wp_customize->add_setting( 'messaggero_postblock_2_style', array(
			'default' => 'light',
			'sanitize_callback' => 'messaggero_select_sanitize',

		));

		$wp_customize->add_control( 'messaggero_postblock_2_style' , array(
			'type' => 'select',
			'section' => 'messaggero_postblock_2',
			'label' => esc_html__('Style','messaggero'),
			'description' => esc_html__('Please select the style of this postblock.','messaggero'),
			'choices'  => array (
			   'light' => esc_html__( 'Light','messaggero'),
			   'dark' => esc_html__( 'Dark','messaggero'),
			),
		));

		$wp_customize->add_section('messaggero_postblock_3', array(
			'title' => esc_html__( 'Messaggero postBlock 3', 'messaggero' ),
			'panel' => 'messaggero_postblock_panel',
		));
	
		$wp_customize->add_setting( 'messaggero_postblock_3_category', array(
			'default' => 'none',
			'sanitize_callback' => 'messaggero_select_sanitize',

		));

		$wp_customize->add_control( 'messaggero_postblock_3_category' , array(
			'type' => 'select',
			'section' => 'messaggero_postblock_3',
			'label' => esc_html__('Category','messaggero'),
			'description' => esc_html__('Please select the category of this postblock.','messaggero'),
			'choices'  => messaggero_get_categories(),
		));
		
		$wp_customize->add_setting( 'messaggero_postblock_3_layout', array(
			'default' => 'disable',
			'sanitize_callback' => 'messaggero_select_sanitize',

		));

		$wp_customize->add_control( 'messaggero_postblock_3_layout' , array(
			'type' => 'select',
			'section' => 'messaggero_postblock_3',
			'label' => esc_html__('Layout','messaggero'),
			'description' => esc_html__('Please select the layout of this postblock.','messaggero'),
			'choices'  => array (
			   'disable' => esc_html__( 'Disable','messaggero'),
			   'module-1' => esc_html__( 'Module 1','messaggero'),
			   'module-2' => esc_html__( 'Module 2','messaggero'),
			   'module-3' => esc_html__( 'Module 3','messaggero'),
			   'module-4' => esc_html__( 'Module 4','messaggero'),
			),
		));

		$wp_customize->add_setting( 'messaggero_postblock_3_style', array(
			'default' => 'light',
			'sanitize_callback' => 'messaggero_select_sanitize',

		));

		$wp_customize->add_control( 'messaggero_postblock_3_style' , array(
			'type' => 'select',
			'section' => 'messaggero_postblock_3',
			'label' => esc_html__('Style','messaggero'),
			'description' => esc_html__('Please select the style of this postblock.','messaggero'),
			'choices'  => array (
			   'light' => esc_html__( 'Light','messaggero'),
			   'dark' => esc_html__( 'Dark','messaggero'),
			),
		));

		$wp_customize->add_section('messaggero_postblock_4', array(
			'title' => esc_html__( 'Messaggero postBlock 4', 'messaggero' ),
			'panel' => 'messaggero_postblock_panel',
		));
	
		$wp_customize->add_setting( 'messaggero_postblock_4_category', array(
			'default' => 'none',
			'sanitize_callback' => 'messaggero_select_sanitize',

		));

		$wp_customize->add_control( 'messaggero_postblock_4_category' , array(
			'type' => 'select',
			'section' => 'messaggero_postblock_4',
			'label' => esc_html__('Category','messaggero'),
			'description' => esc_html__('Please select the category of this postblock.','messaggero'),
			'choices'  => messaggero_get_categories(),
		));
		
		$wp_customize->add_setting( 'messaggero_postblock_4_layout', array(
			'default' => 'disable',
			'sanitize_callback' => 'messaggero_select_sanitize',

		));

		$wp_customize->add_control( 'messaggero_postblock_4_layout' , array(
			'type' => 'select',
			'section' => 'messaggero_postblock_4',
			'label' => esc_html__('Layout','messaggero'),
			'description' => esc_html__('Please select the layout of this postblock.','messaggero'),
			'choices'  => array (
			   'disable' => esc_html__( 'Disable','messaggero'),
			   'module-1' => esc_html__( 'Module 1','messaggero'),
			   'module-2' => esc_html__( 'Module 2','messaggero'),
			   'module-3' => esc_html__( 'Module 3','messaggero'),
			   'module-4' => esc_html__( 'Module 4','messaggero'),
			),
		));

		$wp_customize->add_setting( 'messaggero_postblock_4_style', array(
			'default' => 'light',
			'sanitize_callback' => 'messaggero_select_sanitize',

		));

		$wp_customize->add_control( 'messaggero_postblock_4_style' , array(
			'type' => 'select',
			'section' => 'messaggero_postblock_4',
			'label' => esc_html__('Style','messaggero'),
			'description' => esc_html__('Please select the style of this postblock.','messaggero'),
			'choices'  => array (
			   'light' => esc_html__( 'Light','messaggero'),
			   'dark' => esc_html__( 'Dark','messaggero'),
			),
		));

		$wp_customize->add_setting( 'messaggero_enable_related_posts', array(
			'default' => 'on',
			'sanitize_callback' => 'messaggero_select_sanitize',

		));

		$wp_customize->add_control( 'messaggero_enable_related_posts' , array(
			'type' => 'select',
			'section' => 'settings_section',
			'label' => esc_html__('Related posts','messaggero'),
			'description' => esc_html__('Do you want to display the related posts at the end of each article?','messaggero'),
			'choices'  => array (
			   'off' => esc_html__( 'No','messaggero'),
			   'on' => esc_html__( 'Yes','messaggero'),
			),
		));
		
		function messaggero_select_sanitize ($value, $setting) {
		
			global $wp_customize;
					
			$control = $wp_customize->get_control( $setting->id );
				 
			if ( array_key_exists( $value, $control->choices ) ) {
					
				return $value;
					
			} else {
					
				return $setting->default;
					
			}
			
		}

		function messaggero_checkbox_sanize($input) {
			return $input ? true : false;
		}

	}
	
	add_action( 'customize_register', 'messaggero_customize_register', 11 );

}

/*-----------------------------------------------------------------------------------*/
/* Theme setup */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('messaggero_theme_setup')) {

	function messaggero_theme_setup() {

		load_child_theme_textdomain( 'messaggero', get_stylesheet_directory() . '/languages' );
		
		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/functions/function-style.php' );

		require_once( trailingslashit( get_stylesheet_directory() ) . '/core/templates/post-icon.php' );
		require_once( trailingslashit( get_stylesheet_directory() ) . '/core/templates/before-content.php' );

		require_once( trailingslashit( get_stylesheet_directory() ) . '/core/post-formats/default-format.php' );
		require_once( trailingslashit( get_stylesheet_directory() ) . '/core/post-formats/image-format.php' );
		require_once( trailingslashit( get_stylesheet_directory() ) . '/core/post-formats/link-format.php' );
		require_once( trailingslashit( get_stylesheet_directory() ) . '/core/post-formats/quote-format.php' );
		require_once( trailingslashit( get_stylesheet_directory() ) . '/core/post-formats/page-format.php' );

		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/post/main-article.php' );
		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/post/small-article.php' );
		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/post/hero-article.php' );

		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/modules/module-1.php' );
		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/modules/module-2.php' );
		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/modules/module-3.php' );
		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/modules/module-4.php' );

		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/templates/featured-posts.php' );
		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/templates/media.php' );
		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/templates/post-blocks.php' );
		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/templates/related-posts.php' );
		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/templates/top-section.php' );

		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/sidebars/top-sidebar.php' );

		remove_theme_support( 'custom-logo');

		$defaults = array( 'header-text' => array( 'site-title', 'site-description' ));
		add_theme_support( 'custom-logo', $defaults );

		add_image_size( 'messaggero_small_image', 120, 100, TRUE ); 
		add_image_size( 'messaggero_medium_image', 327, 219, TRUE ); 
		add_image_size( 'messaggero_large_image', 387, 338, TRUE ); 

		if ( !get_theme_mod('avventura_lite_logo_font_size') )
			set_theme_mod( 'avventura_lite_logo_font_size', '60px' );

		if ( !get_theme_mod('avventura_lite_menu_font_weight') )
			set_theme_mod( 'avventura_lite_menu_font_weight', '400' );

		if ( !get_theme_mod('avventura_lite_logo_description_top_margin') )
			set_theme_mod( 'avventura_lite_logo_description_top_margin', '10px' );

	}

	add_action( 'after_setup_theme', 'messaggero_theme_setup', 999);

}

/*-----------------------------------------------------------------------------------*/
/* Widgets init */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('messaggero_widgets_init')) {

	function messaggero_widgets_init() {

		register_sidebar(array(
		
			'name' => esc_html__('Banner widget area','messaggero'),
			'id'   => 'messaggero-banner-widget-area',
			'description'   => esc_html__('This widget area will be shown below the logo (Recommended for the image widget).', 'messaggero'),
			'before_widget' => '<div id="%1$s" class="post-container %2$s"><article class="no-padding">',
			'after_widget'  => '</article></div>',
			'before_title'  => '<h4 class="title">',
			'after_title'   => '</h4>'
		
		));

	}

	add_action( 'widgets_init', 'messaggero_widgets_init' );

}

/*-----------------------------------------------------------------------------------*/
/* MESSAGGERO IS ARCHIVE */
/*-----------------------------------------------------------------------------------*/

if (!function_exists('messaggero_is_archive')) {

	function messaggero_is_archive() {

		if ( 
			is_category() ||
			is_tag() ||
			is_author() ||
			is_year() ||
			is_month()
			
		) {
		
			return true;
		
		} else {
		
			return false;
		
		}

	}

}

/*-----------------------------------------------------------------------------------*/
/* Post class */
/*-----------------------------------------------------------------------------------*/

if (!function_exists('messaggero_post_class')) {

	function messaggero_post_class($classes) {

		if ( !avventura_lite_is_single() ) {

			if ( 
				is_home() ||
				is_archive() ||
				is_search() 
			
			) {

				$classes[] = 'post-container';

			}

		} else if ( avventura_lite_is_single() && avventura_lite_is_woocommerce_active('is_cart') ) {

			$classes[] = 'post-container col-md-12 woocommerce_cart_page';

		} else if ( avventura_lite_is_single() && !avventura_lite_is_woocommerce_active('is_product') ) {

			$classes[] = 'post-container col-md-12';

		} else if ( is_page() ) {

			$classes[] = 'full';

		}

		if ( 
			( is_home() ) ||
			( messaggero_is_archive() ) ||
			( is_search() ) 
		) :

			$classes[] = 'post-container-wrap';

		endif;

		return $classes;

	}

	add_filter('post_class', 'messaggero_post_class');

}

/*-----------------------------------------------------------------------------------*/
/* Set excerpt length */
/*-----------------------------------------------------------------------------------*/   

if (!function_exists('messaggero_excerpt_length')) {

	function messaggero_excerpt_length($length) {

		$limit = $length;

		if ( has_post_thumbnail() ) {

			if ( 
				( is_home() ) ||
				( messaggero_is_archive() ) ||
				( is_search() ) 
			) {

				$limit = 20;

			} else {
			
				$limit = $length;
			
			}
	
		} else {

			$limit = $length;
	
		}
	
		return $limit;
	
	}
	
	add_filter( 'excerpt_length', 'messaggero_excerpt_length', 999 );

}

/*-----------------------------------------------------------------------------------*/
/* BODY CLASS HOOK */
/*-----------------------------------------------------------------------------------*/

if (!function_exists('messaggero_body_class_function')) {

	function messaggero_body_class_function($classes) {

		if ( 
			( is_home() ) ||
			( messaggero_is_archive() ) ||
			( is_search() ) 
		) :

			$classes[] = 'is_blog_section';

		endif;

		if ( 
			avventura_lite_setting('messaggero_sticky_post_grid','on') == 'on' &&
			avventura_lite_setting('messaggero_sticky_slideshow','on') == 'on' 
		) :
			$classes[] = 'sticky_slideshow';
		endif;
		
		return $classes;

	}

	add_filter('body_class', 'messaggero_body_class_function');

}

?>